@@ -14,18 +14,6 @@
 # Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
-# Copyrights (C)
-# for this R-port:
-#   1999 - 2007, Diethelm Wuertz, GPL
-#   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
-#   info@rmetrics.org
-#   www.rmetrics.org
-# for the code accessed (or partly included) from other R-ports:
-#   see R's copyright and license files
-# for the code accessed (or partly included) from contributed R-ports
-# and other sources
-#   see Rmetrics's copyright file
-
 
 ################################################################################
 # FUNCTION:             MDA ESTIMATORS:
@@ -143,7 +131,7 @@ doplot = TRUE, plottype = c("both", "upper"))
     if (plottype == "both") bothTails = TRUE else bothTails = FALSE
 
     # Median Plot:
-    index = which.min(abs(tails-median(tails)))
+    index = which.min(abs(tails-stats::median(tails)))
     DOPLOT = rep(FALSE, length(tails))
     DOPLOT[index] = TRUE
     selected.tail = tails[index]
